@@ -100,11 +100,12 @@ def HostServer(HOST, PORT, connections=5, SO_REUSEADDR=True):
     sock.listen(connections)
     return sock
 
-def ConnectorSocket(HOST, PORT):
+def ConnectorSocket(HOST, PORT, timeout=5):
     """
         Helper function for Socket Classes
     """
     clientsocket = socket.socket(socket.AF_INET, socket.SOCK_STREAM)
+    clientsocket.settimeout(timeout)
     clientsocket.connect((HOST, PORT))
     return  clientsocket
 
@@ -159,7 +160,7 @@ class Data_Storage(object):
         return self.megabytes * 0.001
 
 class Socket_Server_Host:
-    def __init__(self, HOST, PORT, on_connection_open, on_data_recv, on_question, on_connection_close=False, daemon=True, autorun=True, connections=5, SO_REUSEADDR=True, heart_beats=True, heart_beat_wait=20, legacy_buffer_size=1024):
+    def __init__(self, HOST, PORT, on_connection_open, on_data_recv, on_question, on_connection_close=False, daemon=True, autorun=True, connections=5, SO_REUSEADDR=True, heart_beats=True, heart_beat_wait=20, legacy_buffer_size=1024, PYTHONIC_only=False):
         """Host your own Socket server to allows connections to this computer.
 
         Parameters
@@ -206,6 +207,7 @@ class Socket_Server_Host:
         self.connections = {}
         self.on_question = on_question
         self.running = False
+        self.PYTHONIC_only = PYTHONIC_only
         self.legacy_buffer_size = legacy_buffer_size
         if autorun:
             self.Run(connections, daemon, SO_REUSEADDR)
@@ -244,7 +246,7 @@ class Socket_Server_Host:
                     conn.close()
                     return
                 conID = tokening.CreateToken(12, self.connections)
-                connector = Socket_Server_Client(conn, addr, conID, self.on_connection_open, self.on_data_recv, on_question=self.on_question, on_close=self.close_connection, Heart_Beat=self.heart_beats, Heart_Beat_Wait=self.heart_beat_wait, legacy_buffer_size=self.legacy_buffer_size)
+                connector = Socket_Server_Client(conn, addr, self, conID, self.on_connection_open, self.on_data_recv, on_question=self.on_question, on_close=self.close_connection, Heart_Beat=self.heart_beats, Heart_Beat_Wait=self.heart_beat_wait, legacy_buffer_size=self.legacy_buffer_size, PYTHONIC_only=self.PYTHONIC_only)
                 self.connections[conID] = connector
                 time.sleep(0.05)
             except Exception as e:
@@ -297,10 +299,11 @@ class Socket_Server_Host:
 
 class Socket_Server_Client:
 
-    def __init__(self, sock, addr, conID, on_connection_open, on_data, on_question, on_close, Heart_Beat=True, Heart_Beat_Wait=20, legacy_buffer_size=1024):
+    def __init__(self, sock, addr, server, conID, on_connection_open, on_data, on_question, on_close, Heart_Beat=True, Heart_Beat_Wait=20, legacy_buffer_size=1024, PYTHONIC_only=False):
         """CLIENT for Socket_Server_Host"""
         self.socket = sock
         self.addr = addr
+        self.server = server
         self.conID = conID
         self.on_data = on_data
         self.on_close = on_close
@@ -316,7 +319,16 @@ class Socket_Server_Client:
         self.created = essentials.TimeStamp()
         self.heart_beat_wait = Heart_Beat_Wait
         self.heart_beat = Heart_Beat
-        threading.Thread(target=self.__detect_client_type__, args=[on_connection_open]).start()
+        self.PYTHONIC_only = PYTHONIC_only
+        if PYTHONIC_only:
+            self.client_type = PYTHONIC
+            threading.Thread(target=on_connection_open, args=[self]).start()
+            threading.Thread(target=self.__data_rev__, daemon=True).start()
+            if self.heart_beat == True:
+                self.socket.setblocking(1)
+                threading.Thread(target=self.__heart_beat__, daemon=True).start()
+        else:
+            threading.Thread(target=self.__detect_client_type__, args=[on_connection_open]).start()
 
     def __detect_client_type__(self, on_open):
         self.socket.settimeout(2)
@@ -363,9 +375,9 @@ class Socket_Server_Client:
             self.socket.settimeout(0.075)
             self.client_type = LEGACY
 
-        threading.Thread(target=on_open, args=[self]).start()
-
+        threading.Thread(target=on_open, args=[self], daemon=True).start()
         threading.Thread(target=self.__data_rev__, daemon=True).start()
+
         if self.heart_beat == True and self.client_type == PYTHONIC:
             self.socket.setblocking(1)
             threading.Thread(target=self.__heart_beat__, daemon=True).start()
@@ -559,6 +571,7 @@ class Configuration(object):
         self.on_data_recv = on_data_recv
         self.on_question = on_question
         self.on_connection_close = on_connection_close
+        self.server_PYTHONIC_only = False
 
     @property
     def PYTHONIC(self):
@@ -637,13 +650,14 @@ class Socket_Connector:
             raise TimeoutError("No response in time.")
         return self.get_next_data
         
-    def connect(self):
+    def connect(self, timeout=5):
         if self.configuration.WEBONIC:
             raise NotImplementedError("Websocket Clients Haven't been Implemented Yet.")
-        self.socket = ConnectorSocket(self.HOST, self.PORT)
+        self.socket = ConnectorSocket(self.HOST, self.PORT, timeout)
         if self.configuration.PYTHONIC == True:
             self.send({"pythonic": True})
-            time.sleep(2)
+            if self.configuration.server_PYTHONIC_only == False:
+                time.sleep(2)
             if self.configuration.heart_beat == True:
                 threading.Thread(target=self.__heart_beat__, daemon=True).start()
         elif self.configuration.WEBONIC == True:
@@ -748,8 +762,7 @@ class Socket_Connector:
                     data, temp = SocketDownload(self.socket, self.recv_data, self.data_usage.received)
                     self.recv_data = temp
                 except:
-                    self.shutdown()
-                    return
+                    continue
                 if type(data) == type({}) and 'heart_beat_function' in data:
                     pass
                 elif type(data) == type({}) and 'function_ask_response' in data:
@@ -864,7 +877,6 @@ class UDP_Connector(object):
 
     def __init__(self, HOST, PORT, on_data=None, timeout=1, max_buffer=1024):
         self.clientSocket = socket.socket(socket.AF_INET, socket.SOCK_DGRAM)
-        print("connecting to", HOST, PORT)
         self.address = (HOST, PORT)
         self.clientSocket.settimeout(timeout)
         self.max_buffer = max_buffer
@@ -877,7 +889,7 @@ class UDP_Connector(object):
                 except Exception as e:
                     continue
                 if self.on_data != None:
-                    threading.Thread(target=self.on_data, daemon=True, args=[data]).start()
+                    threading.Thread(target=self.on_data, daemon=True, args=[data, address]).start()
 
         threading.Thread(target=data_recv, daemon=True).start()
 
